<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'संयुक्त अरब अमीरात दिरहॅम',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'अफगाण अफगाणी',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'अल्बानियन लेक',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'आर्मेनियन द्रॅम',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'नेदरलँडचा अँटिलीन गिल्डर',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'अँगोलन क्वॅन्झा',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'अर्जेंटाइन पेसो',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'ऑस्ट्रेलियन डॉलर',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'अरुबा फ्लोरिन',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'अझरबैझानी मानाट',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'बोस्निया-हर्जेगोविना विनिमय मार्क',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'बार्बाडियन डॉलर',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'बांगलादेशी टका',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'बल्गेरियन लेव',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'बाहरिनी दिनार',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'बुरुंडियन फ्रँक',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'बर्मुडा डॉलर',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'ब्रुनेई डॉलर',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'बोलिव्हियन बोलिव्हियानो',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'ब्राझिलियन रियाल',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'बहामी डॉलर',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'भूतानी एंगल्ट्रम',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'बोट्सवानन पुला',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'बेलारुशियन रुबल',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'बेलारुशियन रुबल (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'बेलीझ डॉलर',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'कॅनडियन डॉलर',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'काँगोलीज फ्रँक',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'स्विस फ्रँक',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'चिली पेसो',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'चिनी युआन (ऑफशोर)',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'चीनी युआन',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'कोलंबियन पेसो',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'कोस्टारिकन कोलोन',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'क्यूबन विनिमय पेसो',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'क्यूबन पेसो',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'केप व्हर्डेयन एस्कुडो',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'झेक प्रजासत्ताक कोरुना',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'जिबौटियन फ्रँक',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'डॅनिश क्रोन',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'डोमिनिकन पेसो',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'अल्जेरियन दिनार',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'इजिप्शियन पाउंड',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'इरिट्रियन नाक्फा',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'इथिओपियन बिर',
        ],
        'EUR' => [
            0 => '€',
            1 => 'युरो',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'फिजियन डॉलर',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'फॉकलंड आयलंड पाउंड',
        ],
        'GBP' => [
            0 => '£',
            1 => 'ब्रिटिश पाऊंड',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'जॉर्जियन लारी',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'घानीयन सेडी',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'जिब्राल्टर पाउंड',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'गाम्बियन डालासी',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'गिनी फ्रँक',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'ग्वाटेमालाचे क्वेत्झाल',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'गयाना डॉलर',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'हाँगकाँग डॉलर',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'होन्डुरन लेंपिरा',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'क्रोएशियन कूना',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'हैती गोअर्ड',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'हंगेरियन फॉरिन्ट',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'इंडोनेशियन रुपिया',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'ईस्त्रायली न्यू शेकेल',
        ],
        'INR' => [
            0 => '₹',
            1 => 'भारतीय रुपया',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'इराकी दिनार',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'इराणी रियाल',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'आइसलँडिक क्रोना',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'जमैकन डॉलर',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'जॉर्डनियन दिनार',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'जपानी येन',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'केनियन शिलिंग',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'किरगिस्तानी सॉम',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'कंबोडियन रियेल',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'कोमोरियन फ्रँक',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'उत्तर कोरियन वॉन',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'दक्षिण कोरियन वॉन',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'कुवैती दिनार',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'केमेन आयलॅंड डॉलर',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'कझाकिस्तानी तेंगे',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'लाओशियन किप',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'लेबनीज पाउंड',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'श्रीलंकन रुपया',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'लाइबेरियन डॉलर',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'लेसोटो लोटी',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'लिथुआनियन लिटास',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'लाट्व्हियन लाट्झ',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'लिबियाचा दिनार',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'मोरोक्को दिरहॅम',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'मोल्डोवन लेउ',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'मालागासी एरियारी',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'मॅसेडोनियन देनार',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'म्यानमार क्याट',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'मंगोलियन टुग्रिक',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'मॅकॅनीज् पटाका',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'मॉरिटानियन ओगिया (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'मॉरिटानियन ओगिया',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'मॉरिशियन रुपी',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'मालदीवियन रुफिया',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'मालावियन क्वाचा',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'मेक्सिको पेसो',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'मलेशियन रिंगिट',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'मोझांबिकन मेटिकल',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'नमिबियन डॉलर',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'नायजेरियन नायरा',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'निकाराग्वन कोर्डोबा',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'नॉर्वेजियन क्रोन',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'नेपाळी रुपया',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'न्यूझीलँड डॉलर',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'ओमानी रियाल',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'पनामा बाल्बोआ',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'पेरुवियन सोल',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'पापुआ न्यू गिनीयन किना',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'फिलिपिनी पेसो',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'पाकिस्तानी रुपया',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'पोलिश झ्लॉटी',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'पराग्वे ग्वारानी',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'कतारी रियाल',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'रोमानियन लेऊ',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'सर्बियन दिनार',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'रशियन रुबल',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'रवांडा फ्रँक',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'सौदी रियाल',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'सोलोमन आयलँड्स डॉलर',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'सेशेलोईस रुपी',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'सुदानी पाउंड',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'स्वीडिश क्रोना',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'सिंगापूर डॉलर',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'सेंट हेलेना पाउंड',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'सिएरा लिऑनचा लिऑन',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'सोमाली शिलिंग',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'सुरिनामी डॉलर',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'दक्षिण सुदानी पाउंड',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'साओ टोम आणि प्रिन्सिपे डोबरा (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'साओ टोम आणि प्रिन्सिपे डोबरा',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'सीरियन पाउंड',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'स्वाझी लीलांगेनी',
        ],
        'THB' => [
            0 => '฿',
            1 => 'थाई बाहत',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'ताजकीस्तानी सोमोनी',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'तुर्कमेनिस्तानी मानाट',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'ट्यूनिशियन दिनार',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'टोंगन पाआंगा',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'तुर्की लिरा',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'त्रिनिदाद आणि टोबॅगो डॉलर',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'न्यू तैवान डॉलर',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'टांझानियन शिलिंग',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'युक्रेनियन रिवनिया',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'युगांडा शिलिंग',
        ],
        'USD' => [
            0 => '$',
            1 => 'यूएस डॉलर',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'उरुग्वेचा पेसो',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'उझबेकिस्तानी सोम',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'व्हेनेझुएला बोलिव्हार (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'व्हेनेझुएला बोलिव्हार',
        ],
        'VND' => [
            0 => '₫',
            1 => 'व्हिएतनामी डोंग',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'वानुआतु वाटु',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'सामोअन टाला',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'मध्य आफ्रिकन [CFA] फ्रँक',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'पूर्व कॅरीबियन डॉलर',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'पश्चिम आफ्रिकन [CFA] फ्रँक',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => '[CFP] फ्रँक',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'येमेनी रियाल',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'दक्षिण आफ्रिकी रँड',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'झांबियन क्वाचा (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'झांबियन क्वाचा',
        ],
    ],
];
